package com.ruoyi.ss.hardwareVersion.service;

import com.ruoyi.ss.hardwareVersion.domain.HardwareVersion;

import java.util.List;

/**
 * 硬件版本Service接口
 *
 * @author qiuzhenzhao
 * @date 2024-07-22
 */
public interface IHardwareVersionService
{
    /**
     * 查询硬件版本
     *
     * @param id 硬件版本主键
     * @return 硬件版本
     */
    public HardwareVersion selectEHardwareVersionById(Long id);

    /**
     * 查询硬件版本列表
     *
     * @param eHardwareVersion 硬件版本
     * @return 硬件版本集合
     */
    public List<HardwareVersion> selectEHardwareVersionList(HardwareVersion eHardwareVersion);

    /**
     * 新增硬件版本
     *
     * @param eHardwareVersion 硬件版本
     * @return 结果
     */
    public int insertEHardwareVersion(HardwareVersion eHardwareVersion);

    /**
     * 修改硬件版本
     *
     * @param eHardwareVersion 硬件版本
     * @return 结果
     */
    public int updateEHardwareVersion(HardwareVersion eHardwareVersion);

    /**
     * 批量删除硬件版本
     *
     * @param ids 需要删除的硬件版本主键集合
     * @return 结果
     */
    public int deleteEHardwareVersionByIds(Long[] ids);

    /**
     * 删除硬件版本信息
     *
     * @param id 硬件版本主键
     * @return 结果
     */
    public int deleteEHardwareVersionById(Long id);
}
